summaryrefslogtreecommitdiffstats
path: root/libk9copy/dvdprogress.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
commitb0e912c8b3d02a518fedda28c3180eb4794a7520 (patch)
tree07d344862562fab58cbe2df39d13d16f2e4d2bea /libk9copy/dvdprogress.cpp
parent4d695ec81fe4d4335ee82c7a9346ad9c9e144ecc (diff)
downloadk9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.tar.gz
k9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.zip
TQt4 convert k9copy
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k9copy@1233843 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libk9copy/dvdprogress.cpp')
-rw-r--r--libk9copy/dvdprogress.cpp78
1 files changed, 39 insertions, 39 deletions
diff --git a/libk9copy/dvdprogress.cpp b/libk9copy/dvdprogress.cpp
index 273e551..83e37a5 100644
--- a/libk9copy/dvdprogress.cpp
+++ b/libk9copy/dvdprogress.cpp
@@ -9,68 +9,68 @@
#include "dvdprogress.h"
-#include <qvariant.h>
-#include <qpushbutton.h>
-#include <qlabel.h>
-#include <qprogressbar.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqvariant.h>
+#include <tqpushbutton.h>
+#include <tqlabel.h>
+#include <tqprogressbar.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
/*
* Constructs a DVDProgress as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*
* The dialog will by default be modeless, unless you set 'modal' to
* TRUE to construct a modal dialog.
*/
-DVDProgress::DVDProgress( QWidget* parent, const char* name, bool modal, WFlags fl )
- : QDialog( parent, name, modal, fl )
+DVDProgress::DVDProgress( TQWidget* tqparent, const char* name, bool modal, WFlags fl )
+ : TQDialog( tqparent, name, modal, fl )
{
if ( !name )
setName( "DVDProgress" );
- setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)5, (QSizePolicy::SizeType)5, 0, 0, sizePolicy().hasHeightForWidth() ) );
- setMinimumSize( QSize( 0, 150 ) );
- setMaximumSize( QSize( 400, 150 ) );
- setCursor( QCursor( 3 ) );
- DVDProgressLayout = new QGridLayout( this, 1, 1, 11, 6, "DVDProgressLayout");
+ tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)5, (TQSizePolicy::SizeType)5, 0, 0, sizePolicy().hasHeightForWidth() ) );
+ setMinimumSize( TQSize( 0, 150 ) );
+ setMaximumSize( TQSize( 400, 150 ) );
+ setCursor( TQCursor( 3 ) );
+ DVDProgressLayout = new TQGridLayout( this, 1, 1, 11, 6, "DVDProgressLayout");
- layout2 = new QVBoxLayout( 0, 0, 6, "layout2");
+ tqlayout2 = new TQVBoxLayout( 0, 0, 6, "tqlayout2");
- lblTotal = new QLabel( this, "lblTotal" );
- lblTotal->setCursor( QCursor( 3 ) );
- layout2->addWidget( lblTotal );
+ lblTotal = new TQLabel( this, "lblTotal" );
+ lblTotal->setCursor( TQCursor( 3 ) );
+ tqlayout2->addWidget( lblTotal );
- pbTotal = new QProgressBar( this, "pbTotal" );
- pbTotal->setCursor( QCursor( 3 ) );
+ pbTotal = new TQProgressBar( this, "pbTotal" );
+ pbTotal->setCursor( TQCursor( 3 ) );
pbTotal->setProgress( 100 );
pbTotal->setPercentageVisible( FALSE );
- layout2->addWidget( pbTotal );
+ tqlayout2->addWidget( pbTotal );
- DVDProgressLayout->addLayout( layout2, 1, 0 );
+ DVDProgressLayout->addLayout( tqlayout2, 1, 0 );
- layout1 = new QVBoxLayout( 0, 0, 6, "layout1");
+ tqlayout1 = new TQVBoxLayout( 0, 0, 6, "tqlayout1");
- lblTitle = new QLabel( this, "lblTitle" );
- lblTitle->setCursor( QCursor( 3 ) );
- layout1->addWidget( lblTitle );
+ lblTitle = new TQLabel( this, "lblTitle" );
+ lblTitle->setCursor( TQCursor( 3 ) );
+ tqlayout1->addWidget( lblTitle );
- pbTitle = new QProgressBar( this, "pbTitle" );
- pbTitle->setCursor( QCursor( 3 ) );
+ pbTitle = new TQProgressBar( this, "pbTitle" );
+ pbTitle->setCursor( TQCursor( 3 ) );
pbTitle->setTotalSteps( 100 );
pbTitle->setProgress( 100 );
pbTitle->setCenterIndicator( TRUE );
pbTitle->setPercentageVisible( FALSE );
- layout1->addWidget( pbTitle );
+ tqlayout1->addWidget( pbTitle );
- DVDProgressLayout->addLayout( layout1, 0, 0 );
+ DVDProgressLayout->addLayout( tqlayout1, 0, 0 );
- lblStatus = new QLabel( this, "lblStatus" );
- lblStatus->setCursor( QCursor( 3 ) );
+ lbltqStatus = new TQLabel( this, "lbltqStatus" );
+ lbltqStatus->setCursor( TQCursor( 3 ) );
- DVDProgressLayout->addWidget( lblStatus, 2, 0 );
+ DVDProgressLayout->addWidget( lbltqStatus, 2, 0 );
languageChange();
- resize( QSize(278, 150).expandedTo(minimumSizeHint()) );
+ resize( TQSize(278, 150).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
}
@@ -79,7 +79,7 @@ DVDProgress::DVDProgress( QWidget* parent, const char* name, bool modal, WFlags
*/
DVDProgress::~DVDProgress()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*
@@ -89,9 +89,9 @@ DVDProgress::~DVDProgress()
void DVDProgress::languageChange()
{
setCaption( tr2i18n( "k9Copy - DVD Analyze" ) );
- lblTotal->setText( QString::null );
- lblTitle->setText( QString::null );
- lblStatus->setText( QString::null );
+ lblTotal->setText( TQString() );
+ lblTitle->setText( TQString() );
+ lbltqStatus->setText( TQString() );
}
#include "dvdprogress.moc"
@@ -9,68 +9,68 @@
/*
- * Constructs a DVDProgress as a child of 'parent', with the
+ * Constructs a DVDProgress as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*